@@ -11,10 +11,9 @@ public:
     QList<QString> openGroup(QString group);
     //int saveNewEx( QDomDocument &d, QString name, QString group, QString muscle,
       //             QString info);
-    void saveDoneEx(QString group, QString name, QString kg, QString currentReps);
+    void saveDoneEx(QString group, QString name, QString kg, QString reps, QString status);
     void saveSettings(QString vibrate, QString sound, QString volume
-                      ,QString set, QString reps1, QString reps2, QString reps3,
-                      QString currentReps, QString min, QString sec, QString calories);
+                      ,QString set, QString min, QString sec, QString calories);
     void saveEx(QString name, QString group, QString muscle,
                    QString info);
     QList <QString> loadSettings();
@@ -24,7 +23,6 @@ public:
     QList <QString> loadProgram(QString name);
     QList <QString> getPrograms();
 
-    void updateLastWeight(QString name, QString weight, QString status, QString reps);
 
     void removeElement(QString name);
 
@@ -36,6 +34,7 @@ public:
     QList< QList <QString> > readHistory();
     QList <QString> getDates();
     QList < QList<QString> > getHistoryByDate(QString date);
+    QList<QString> getHistoryByExercise(QString name);
 
     void saveFood(QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat);
     QList<QString> openIngredients();
@@ -53,10 +52,9 @@ private:
     QDomElement createExerciseNode( QDomDocument &d, QString name, QString group, QString muscle,
                                QString info);
     QDomElement createCardioNode( QDomDocument &d, QString name);
-    QDomElement createHistoryNode(QDomDocument &d, QString group, QString name, QString date, QString kg, QString currentReps);
+    QDomElement createHistoryNode(QDomDocument &d, QString group, QString name, QString date, QString kg, QString reps, QString status);
     QDomElement createSettingsNode( QDomDocument &d, QString vibrate, QString sound, QString volume,
-                               QString set, QString reps1, QString reps2, QString reps3, QString currentReps,
-                               QString min, QString sec, QString calories);
+                               QString set, QString min, QString sec, QString calories);
     QDomElement createProgramNode(QDomDocument &d, QString name, QModelIndexList exercises);
 };
 
